import * as api from './api';
import { dict, UserPageQuery, AddReq, DelReq, EditReq, compute, CreateCrudOptionsProps, CreateCrudOptionsRet } from '@fast-crud/fast-crud';
import { dictionary } from '/@/utils/dictionary';
import { successMessage } from '/@/utils/message';
import { auth } from '/@/utils/authFunction';
import tableSelector from '/@/components/tableSelector/index.vue';
import { shallowRef } from 'vue';
import { useRouter } from 'vue-router';
import { Plus } from '@element-plus/icons-vue';

export const createCrudOptions = function ({ crudExpose }: CreateCrudOptionsProps): CreateCrudOptionsRet {
	const router = useRouter();
	
	const pageRequest = async (query: UserPageQuery) => {
		return await api.GetList(query);
	};
	const editRequest = async ({ form, row }: EditReq) => {
		form.id = row.id;
		return await api.UpdateObj(form);
	};
	const delRequest = async ({ row }: DelReq) => {
		return await api.DelObj(row.id);
	};
	const addRequest = async ({ form }: AddReq) => {
		return await api.AddObj(form);
	};

	/**
	 * 懒加载
	 * @param row
	 * @returns {Promise<unknown>}
	 */
	const loadContentMethod = (tree: any, treeNode: any, resolve: Function) => {
		pageRequest({ pcode: tree.code }).then((res: APIResponseData) => {
			resolve(res.data);
		});
	};

	return {
		crudOptions: {
			request: {
				pageRequest,
				addRequest,
				editRequest,
				delRequest,
			},
			actionbar: {
				buttons: {
					add: {
						show: true//auth('digitalHuma:Create'),
					},
				},
			},
			rowHandle: {
				//固定右侧
				fixed: 'right',
				width: 200,
				buttons: {
					view: {
						iconRight: 'view',
						show: true,
						type: 'text',
						click: ({ row }) => {
							// 查看数字人详情
							// router.push({
							// 	path: '/digitalHuman/detail',
							// 	query: { id: row.id }
							// });
						}
					},
					edit: {
						iconRight: 'Edit',
						type: 'text',
						show: false,//auth('digitalHuma:Update'),
						click: ({ row }) => {
							// 编辑数字人
							router.push({
								path: '/digitalHuman/edit',
								query: { id: row.id }
							});
						}
					},
					remove: {
						iconRight: 'Delete',
						type: 'text',
						show: false//	auth('digitalHuma:Delete'),
					},
				},
			},
			pagination: {
				show: true,
			},
			table: {
				rowKey: 'id',
			},
			search: {
				show: true,
				layout: 'auto',
			},
			columns: {
				_index: {
					title: '序号',
					form: { show: false },
					column: {
						type: 'index',
						align: 'center',
						width: '70px',
						columnSetDisabled: true, //禁止在列设置中选择
					},
				},
				name: {
					title: '数字人名称',
					search: {
						show: true,
						component: {
							placeholder: '请输入数字人名称',
						},
					},
					type: 'input',
					column: {
						minWidth: 150,
					},
					form: {
						rules: [
							{ required: true, message: '数字人名称为必填项' },
						],
					},
				},
				description: {
					title: '描述',
					search: {
						show: false,
					},
					type: 'textarea',
					column: {
						minWidth: 200,
						showOverflowTooltip: true,
					},
					form: {
						component: {
							span: 24,
						},
					},
				},
				avatar_url: {
					title: '头像',
					type: 'image-uploader',
					form: {
						component: {
							uploader: {
								action: '/api/system/admin_upload/',
								multiple: false,
								limit: 1,
								accept: '.jpg,.png,.jpeg',
								headers: () => {
									return {
										'Authorization': `JWT ${localStorage.getItem('token') || ''}`
									}
								},
								data: {
									tenant_id: '1'
								},
								onSuccessHandle(res: any) {
									// 返回上传后的URL
									return res.data.url;
								},
								beforeUpload(file: File) {
									const isImage = file.type.startsWith('image/');
									const isLt2M = file.size / 1024 / 1024 < 2;
									
									if (!isImage) {
										this.$message.error('只能上传图片文件!');
										return false;
									}
									if (!isLt2M) {
										this.$message.error('图片大小不能超过 2MB!');
										return false;
									}
									return true;
								}
							},
							slots: {
								default: ({modelValue}) => {
									return modelValue ? 
										<img src={modelValue} class="avatar" style="width:100px;height:100px;"/> : 
										<el-icon class="avatar-uploader-icon"><Plus /></el-icon>
								}
							}
						},
						rules: [
							{ required: true, message: '请上传头像' }
						]
					},
					column: {
						component: {
							name: 'fs-image',
							style: {width: '50px', height: '50px'},
						}
					}
				},
				status: {
					title: '状态',
					search: {
						show: true,
						component: {
							name: 'el-select',
							placeholder: '请选择状态',
						},
					},
					type: 'dict-select',
					column: {
						minWidth: 100,
					},
					dict: dict({
						data: [
							{ value: 1, label: '启用' },
							{ value: 0, label: '禁用' },
						],
					}),
				},
				config: {
					title: '配置信息',
					type: 'text',
					column: {
						minWidth: 150,
						formatter: (row) => {
							if (row.config) {
								return `风格: ${row.config.style}, 语音ID: ${row.config.voice_id}`;
							}
							return '';
						},
						showOverflowTooltip: true,
					},
					form: {
						component: {
							name: 'el-card',
							header: '配置信息',
							children: {
								style: {
									title: '风格设置',
									value: 'professional',
									component: {
										name: 'el-select',
										options: [
											{ value: 'professional', label: '专业' },
											{ value: 'friendly', label: '友好' },
											{ value: 'serious', label: '严肃' },
											{ value: 'casual', label: '随意' }
										]
									}
								},
								voice_id: {
									title: '语音设置',
									value: 'xiaoming_voice_premium',
									component: {
										name: 'el-select',
										options: [
											{ value: 'xiaoming_voice_premium', label: '小明(高级)' },
											{ value: 'xiaohong_voice_premium', label: '小红(高级)' },
											{ value: 'xiaohong_voice', label: '小红' }
										]
									}
								}
							}
						}
					}
				},
				creator_name: {
					title: '创建人',
					type: 'text',
					column: {
						minWidth: 120,
					},
					form: {
						show: false,
					},
				},
				create_datetime: {
					title: '创建时间',
					type: 'datetime',
					column: {
						minWidth: 160,
					},
					form: {
						show: false,
					},
				},
				update_datetime: {
					title: '更新时间',
					type: 'datetime',
					column: {
						minWidth: 160,
					},
					form: {
						show: false,
					},
				},
			},
		},
	};
};
