import { CreateCrudOptionsProps, CreateCrudOptionsRet, AddReq, DelReq, EditReq, dict, compute } from '@fast-crud/fast-crud';
import * as api from './api';
import { dictionary } from '/@/utils/dictionary';
import { successMessage } from '../../../utils/message';
import { auth } from '/@/utils/authFunction';

/**
 *
 * @param crudExpose：index传递过来的示例
 * @param context：index传递过来的自定义参数
 * @returns
 */
export const createCrudOptions = function ({ crudExpose, context }: CreateCrudOptionsProps): CreateCrudOptionsRet {
	const pageRequest = async (query: any) => {
		return await api.GetList(query);
	};
	const editRequest = async ({ form, row }: EditReq) => {
		form.id = row.id;
		return await api.UpdateObj(form);
	};
	const delRequest = async ({ row }: DelReq) => {
		return await api.DelObj(row.id);
	};
	const addRequest = async ({ form }: AddReq) => {
		return await api.AddObj(form);
	};

	return {
		crudOptions: {
			request: {
				pageRequest,
				addRequest,
				editRequest,
				delRequest,
			},
			pagination: {
				show: true,
			},
			actionbar: {
				buttons: {
					add: {
						show: auth('role:Create'),
					},
				},
			},
			rowHandle: {
				//固定右侧
				fixed: 'right',
				width: 320,
				buttons: {
					view: {
						show: true,
						icon:"View",
						type:"text"
					},
					edit: {
						show: auth('role:Update'),
						icon:"Edit",
						type:"text"
					},
					remove: {
						show: auth('role:Delete'),
						icon:"Delete",
						type:"text"
					},
					qrcode: {
						text: '小程序码',
						type: "text",
						icon: '',
						click: (ctx) => {
							context.generateQRCode(ctx.row);
						},
						order: 4
					},
					/* permission: {
						type: 'primary',
						text: '权限配置',
						show: auth('role:Permission'),
						click: (clickContext: any): void => {
							const { row } = clickContext;
							context.RoleDrawer.handleDrawerOpen(row);
							context.RoleMenuBtn.setState([]);
							context.RoleMenuField.setState([]);
						},
					}, */
				},
			},
			form: {
				col: { span: 24 },
				labelWidth: '100px',
				wrapper: {
					is: 'el-dialog',
					width: '600px',
				},
			},
			columns: {
				/* _index: {
					title: '序号',
					form: { show: false },
					column: {
						type: 'index',
						align: 'center',
						width: '70px',
						columnSetDisabled: true, //禁止在列设置中选择
					},
				}, */
				id: {
					title: 'ID',
					column: { show: false },
					search: { show: false },
					form: { show: false },
				},
				title: {
					title: '职位名称',
					search: { show: true },
					column: {
						minWidth: 120,
						sortable: 'custom',
					},
					form: {
						rules: [{ required: true, message: '角色名称必填' }],
						component: {
							placeholder: '请输入角色名称',
						},
					},
				},
				/* key: {
					title: '权限标识',
					search: { show: false },
					column: {
						minWidth: 120,
						sortable: 'custom',
						columnSetDisabled: true,
					},
					form: {
						rules: [{ required: true, message: '权限标识必填' }],
						component: {
							placeholder: '输入权限标识',
						},
					},
					valueBuilder(context) {
						const { row, key } = context;
						return row[key];
					},
				},
				sort: {
					title: '排序',
					search: { show: false },
					type: 'number',
					column: {
						minWidth: 90,
						sortable: 'custom',
					},
					form: {
						rules: [{ required: true, message: '排序必填' }],
						value: 1,
					},
				},*/
				job_type_display: {
					title: '职位类型',
					search: { show: true },
					type: 'dict-select',
					column: {
						width: 100,
					},
					dict: dict({
						data: [
							{ value: "全职", label: '全职' },
							{ value: "兼职", label: '兼职' },
							{ value: "实习", label: '实习' },
							{ value: "其他", label: "其他" }
						]
					}),
					form: {
						rules: [{ required: true, message: '职位类型必填' }],
						component: {
							placeholder: '职位类型',
						},
					},
				},
				salary_range: {
					title: '薪资范围',
					search: { show: true },
					column: {
						minWidth: 100,
					},
					form: {
						rules: [{ required: true, message: '薪资范围必填' }],
						component: {
							placeholder: '请输入薪资范围',
						},
					},
				},
				location: {
					title: '工作地点',
					search: { show: true },
					column: {
						minWidth: 120,
						formatter: ({ row }) => {
							if (Array.isArray(row.location)) {
								return row.location.join(' ');
							}
							if (row.province && row.city) {
								return row.province + ' ' + row.city + (row.district ? ' ' + row.district : '');
							}
							return row.location || '';
						}
					},
					form: {
						component: {
							name: 'el-cascader',
							props: {
								options: [
									{
										value: '上海市',
										label: '上海市',
										children: [
											{
												value: '浦东新区',
												label: '浦东新区',
												children: [
													{ value: '张江', label: '张江' },
													{ value: '金桥', label: '金桥' },
													{ value: '陆家嘴', label: '陆家嘴' }
												]
											},
											{
												value: '徐汇区',
												label: '徐汇区',
												children: [
													{ value: '漕河泾', label: '漕河泾' },
													{ value: '徐家汇', label: '徐家汇' }
												]
											},
											// 其他区域...
										]
									},
									{
										value: '北京市',
										label: '北京市',
										children: [
											{
												value: '海淀区',
												label: '海淀区',
												children: [
													{ value: '中关村', label: '中关村' },
													{ value: '上地', label: '上地' }
												]
											},
											{
												value: '朝阳区',
												label: '朝阳区',
												children: [
													{ value: 'CBD', label: 'CBD' },
													{ value: '望京', label: '望京' }
												]
											},
											// 其他区域...
										]
									},
									// 其他省市...
								],
								props: {
									expandTrigger: 'hover',
									checkStrictly: false
								},
								placeholder: '请选择工作地点',
								clearable: true,
								showAllLevels: true
							},
							on: {
								change: (value) => {
									console.log('地址选择变化:', value);
								}
							}
						},
						valueResolve: (form: any) => {
							if (form.location && Array.isArray(form.location) && form.location.length > 0) {
								form.province = form.location[0];
								form.city = form.location[1] || '';
								form.district = form.location[2] || '';
								form.location = form.location.join(' ');
							}
						},
						valueBuilder: (form: any) => {
							if (form.province && form.city) {
								form.location = [form.province, form.city];
								if (form.district) {
									form.location.push(form.district);
								}
							} else if (typeof form.location === 'string' && form.location) {
								const parts = form.location.split(' ');
								if (parts.length > 0) {
									form.location = parts;
								}
							}
						}
					},
				},
				department: {
					title: '所属部门',
					search: { show: true },
					column: {
						minWidth: 100,
					},
					form: {
						rules: [{ required: true, message: '所属部门必填' }],
						component: {
							placeholder: '请输入所属部门',
						},
					},
				},
				job_type: {
					title: '状态',
					search: { show: true },
					type: 'dict-select',
					column: {
						minWidth: 100,
					},
					dict: dict({
						data: [
							{ value: 0, label: '未发布' },
							{ value: 1, label: '已发布' },
							{ value: 2, label: '已结束' }
						]
					}),
					form: {
						rules: [{ required: true, message: '职位类型必填' }],
					},
				},
				end_date: {
					title: '截止日期',
					type: 'datetime',
					search: { show: true },
					column: {
						minWidth: 150,
						sortable: 'custom',
					},
					form: {
						rules: [{ required: true, message: '截止日期必填' }],
						component: {
							type: 'datetime',
							valueFormat: 'YYYY-MM-DD HH:mm:ss',
							placeholder: '请选择截止日期',
						},
					},
				},
				requirements: {
					title: '职位要求',
					search: { show: false },
					column: {
						minWidth: 120,
					},
					form: {
						component: {
							type: 'textarea',
							rows: 4,
						},
					},
				},
				description: {
					title: '职位描述',
					search: { show: false },
					column: {
						minWidth: 120,
					},
					form: {
						component: {
							type: 'textarea',
							rows: 4,
						},
					},
				},
				province: {
					title: '省份',
					column: { show: false },
					form: { show: false }
				},
				city: {
					title: '城市',
					column: { show: false },
					form: { show: false }
				},
				district: {
					title: '区域',
					column: { show: false },
					form: { show: false }
				},
			},
		},
	};
};
